# Distributions
## A Python package for Udacity MAchine Learning Engineer course

This package is created for the first module of the ML Eng course on Udacity abount software development: it covers OOP basics and packaging.

This class creates Distribution objects with the same properties as statistical distributions. For now, we have Gaussian and Binomial distributions.